hmLoadTopic({
hmKeywords:"Profiles,Profiles WebDAV,WebDAV",
hmTitle:"WebDAV Profile Settings",
hmDescription:"URL, Username, Password, Recursive listings Specify parameters for your account. The Description can include any text you want.",
hmPrevLink:"profilesvn.html",
hmNextLink:"admin_policies.html",
hmParentLink:"dlgprofilemanager.html",
hmBreadCrumbs:"<a href=\"settings_reference.html\">Settings Reference<\/a> &gt; <a href=\"dlgprofilemanager.html\">Profiles<\/a>",
hmTitlePath:"Settings Reference > Profiles > WebDAV Profiles",
hmHeader:"<h1 class=\"p_Heading1\"><span class=\"f_Heading1\">WebDAV Profile Settings<\/span><\/h1>\n\r",
hmBody:"<p class=\"p_Command\"><span class=\"f_Command\">URL<\/span>, <span class=\"f_Command\">Username<\/span>, <span class=\"f_Command\">Password<\/span>, <span class=\"f_Command\">Recursive listings<\/span><\/p>\n\r<p class=\"p_Normal\">Specify parameters for your account.<\/p>\n\r<p class=\"p_Normal\">The <span class=\"f_Command\">Description<\/span> can include any text you want.<\/p>\n\r"
})
